<?php

// Exit if accessed directly.
if ( ! defined( 'ABSPATH' ) ) {
    exit;
}

/**
 * MonsterInsights PPC Tracking - WooCommerce tracking class.
 *
 * @access public
 * @since 2.0.0
 *
 * @package MonsterInsights_PPC_Tracking
 * @subpackage Ecommerce_Providers
 * @author  David Paternina
 */

class MonsterInsights_PPC_Tracking_Ecommerce_Woo extends MonsterInsights_PPC_Tracking_Ecommerce_Tracking
{
    /**
     * WooCommerce order
     *
     * @var $order WC_Order
     */
    protected $order;

    /**
     * @inheritdoc
     */
    public function do_conversion_checks() {
        return function_exists( 'is_order_received_page' ) && is_order_received_page();
    }

    /**
     * @inheritdoc
     */
    public function is_active() {
        return class_exists( 'WooCommerce' ) && apply_filters( 'MonsterInsights_PPC_Tracking_track_conversion_woocommerce', true );
    }

    /**
     * @inheritdoc
     */
    public function try_to_get_order() {
        $order_id = absint( get_query_var( 'order-received' ) );

        if ( empty( $order_id ) ) {
            return false;
        }

        $this->order = wc_get_order( $order_id );
        return true;
    }

    /**
     * @inheritDoc
     */
    function get_order_total() {
        return empty( $this->order ) ? null : $this->order->get_total();
    }

    /**
     * @inheritDoc
     */
    function get_order_currency() {
        return empty( $this->order ) ? null : $this->order->get_currency();
    }

    /**
     * @inheritDoc
     */
    function get_order_number() {
        return empty( $this->order ) ? null : $this->order->get_id();
    }

    /**
     * @inheritDoc
     */
    function already_tracked( $provider_id ) {
        if ( empty( $this->order ) ) {
            return true;
        }

        $tracked = $this->order->get_meta( "_MonsterInsights_PPC_Tracking_conversion_tracked_{$provider_id}" );

        return ! empty( $tracked ) && 'yes' === $tracked;
    }

    /**
     * @inheritDoc
     */
    function mark_order_tracked( $provider_id ) {
        if ( empty( $this->order ) ) {
            return;
        }

        $this->order->add_meta_data( "_MonsterInsights_PPC_Tracking_conversion_tracked_{$provider_id}", 'yes', true );
        $this->order->save_meta_data();
    }

    /**
     * @inheritdoc
     */
    public function get_name()
    {
        return 'WooCommerce';
    }
}
